// udStFiLrIRData
// Jeffrey J Weimer
// developed from utilities created by J. Gutow
// SVN History: $Revision: 815 $ on $Date: 2008-07-08 13:26:10 -0500 (Tue, 08 Jul 2008) $

#pragma rtGlobals=1
#pragma IgorVersion=6.03
#pragma version = 1.0

#include "udFLStandardFunctions", version >= 2.0

#include "udIRModule_Polaris"
#include "udIRModule_JCAMP"
#include "udIRModule_JDX"

// **********************************************
// Globals and Localizations

Static Constant kVersion = 1.0

// **********************************************
// Initialize (Zero + Query + Check for PlugIns)

Static Function udFLIRDInititalize(udFL)
	STRUCT udFLStandardStructure &udFL
	
	udFLZeroStructure(udFL)
	udFLIRDQuery(udFL)
	return 0
end

Static Function udFLIRDQuery(udFL)
	STRUCT udFLStandardStructure &udFL
		
	udFL.mimetype = "????"
	udFL.extensions = ".abs;.jdx;"
#if(exists("JCAMPLoadWave")==4)
	udFL.extensions += ".dx;"
#endif
	udFL.loadModes += "Manual;"
	udFL.itemsType = 4			// returns waves
	udFL.itemsDim[p] = p*0
	udFL.itemsDim[0]=-1		// waves are nominally unscaled numeric
	udFL.setNames=(2+8)		// filename+number or prefix+number supported
	udFLIRDInitPlugIns(udFL)
	return 0	
end

// **********************************************
// Check for PlugIns

Static Function udFLIRDInitPlugIns(udFL)
	STRUCT udFLStandardStructure &udFL

	udFLCheckForPlugIn("udFLPlugInLinkDisplay",udFL)
	return 0
end

// **********************************************
// File Loader

Function udStFiLrIRData(udFL)
	STRUCT udFLStandardStructure &udFL

	variable ic, nt
	string pathStr, wavesLoaded
	
	switch(udFL.userLCtrl)
		case -1:		// initialize		
			udFLIRDInititalize(udFL)		
			return 0
		case 0:		// query
			udFLIRDQuery(udFL)
			return 0
		case 1:		// auto
			if (strlen(udFL.fileList)==0)
				udFLSetError(udFL,"No files in the selection list!",-1)
				return -1
			endif
			break
		case 2:		// manual
			if (pickIRFile(udFL) <= 0)
				return -1
			endif
			break
	endswitch

	if (udFL.reportCtrl >= 1)
		print "LOADING IR DATA"
		print "... assuring file paths"
	endif
	if (udFLAssureFilePaths(udFL)<0)
		return -1
	endif
	
	if (udFL.reportCtrl >= 1)
		print "... setting data folder location"
	endif
	string cdf = GetDataFolder(1)
	udFLSetDataFolder(udFL)
	if (strlen(udFL.pathStr)!=0)
		pathStr = udFL.pathStr
		NewPath/O/Q tmpIRDatadir, pathStr
	endif

	if (udFL.reportCtrl >= 1)
		print "... loading"
	endif
		
	nt = ItemsInList(udFL.fileList)
	for (ic=0;ic<nt;ic+=1)
			
		WavesLoaded = LoadIRFile(ic,udFL)
		
		if (strlen(WavesLoaded)!=0)
				
//			WavesLoaded = ProcessIRWaves(WavesLoaded, udFL)
			WavesLoaded = RenameIRWaves(ic,WavesLoaded, udFL)
//			WavesLoaded = DoUserDataIRWaves(WavesLoaded, udFL)
			LinkIRWaves(WavesLoaded,udFL)
			udFL.itLst.WAVES += WavesLoaded
				
		endif
		
	endfor
	
	udFL.itemsCount = ItemsInList(udFL.itLst.WAVES)
	
	SetDataFolder $cdf
	
	if (udFL.reportCtrl == 2)
		print "Structure @ Loader:", udFL
	endif
	
	return 0
	
//	if (GetIRFiles(udFL) < 0)
//		SetDataFolder $cdf
//		return -1
//	endif	
//	
//	if (udFL.reportCtrl == 2)
//		print "Structure @ Loader:", udFL
//	endif
//	
//	return 0
end

Static Function pickIRFile(udFL)
	STRUCT udFLStandardStructure &udFL

	variable refNum
	
	// select a file

	Open/D/M="Select the IR data file"/R/T=udFL.mimeType refNum

	if (strlen(S_filename)!=0)
		udFL.filelist = S_filename + ";"
		close refNum
		return refNum
	else
		udFLSetError(udFL,"No file selected",-1)
		return -1
	endif
end

Static Function/S LoadIRFile(ic, udFL)
	variable ic
	STRUCT udFLStandardStructure &udFL

	variable sysT, fileRef
	string wavesLoaded, theExt
	string fileStr = StringFromList(ic,udFL.fileList)
	
	theExt = ParseFilePath(4,fileStr,":",0,0)
	
	strswitch (LowerStr(theExt))
		case "abs":	// Mattson Polaris absorbance files		
			wavesLoaded = IRPolaris#LoadPolaris(ic, udFL)
			break
		case "dx":    	// JCAMP
			wavesLoaded = IRJCAMP#LoadJCAMP(ic, udFL)
			break
		case "jdx":	// JDX
			wavesLoaded = IRJDX#LoadJDX(ic, udFL)
			break
	endswitch
	
	return wavesLoaded
end

// **********************************************
// Rename Waves

Static Function/S RenameIRWaves(ic,WavesLoaded,udFL)
	variable ic
	string WavesLoaded
	STRUCT udFLStandardStructure &udFL

	string fileStr = StringFromList(ic,udFL.fileList)
		
	switch(udFL.setNames)
		case 1:
			WavesLoaded=udFLRenameInput(WavesLoaded,"IRwave")
			break
		case 2:
			udFL.namePrefix = ReplaceString(" ",ParseFilePath(3,fileStr,":",0,0),"")
			if (udFL.reportCtrl >= 1)
				print "... renaming wave(s) by filename ", udFL.namePrefix, " + number"
			endif
			WavesLoaded=udFLRenameInput(WavesLoaded,udFL.namePrefix)
			break
		case 8:
			if (udFL.reportCtrl >= 1)
				print "... renaming wave(s) by prefix ", udFL.namePrefix, " + number"
			endif
			WavesLoaded=udFLRenameInput(WavesLoaded,udFL.namePrefix)
			break
	endswitch
	return WavesLoaded
end

// **********************************************
// (possibly) Link the Waves

Static Function LinkIRWaves(WavesLoaded,udFL)
	string WavesLoaded
	STRUCT udFLStandardStructure &udFL

	string wList = udFL.itLst.WAVES

#if(exists("udFLPlugInLinkDisplay")==6)
	udFL.userPCtrl+=-1
	udFL.itLst.WAVES=WavesLoaded
	udFLPlugInLinkDisplay(udFL)
	udFL.itLst.WAVES=wList
	udFL.userPCtrl+=1
#endif

	return 0
end
